/* hide CREATE button */
.cms-toolbar-item.cms-toolbar-item-buttons .cms-btn[data-rel="modal"] {
  display: none; }

div.cms .cms-structure,
#cms_toolbar .cms_structure .cms_structure-dimmer {
  background: rgba(240, 240, 240, 0.96) !important; }

.cms-modal-head .cms-modal-title-suffix {
  display: none; }
