# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2020-02-11 16:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('test_app', '0004_testpluginmodel_field1_fr'),
    ]

    operations = [
        migrations.AddField(
            model_name='testpluginmodel',
            name='field_date',
            field=models.DateField(default=None, null=True),
        ),
        migrations.AddField(
            model_name='testpluginmodel',
            name='field_datetime',
            field=models.DateTimeField(default=None, null=True),
        ),
        migrations.AddField(
            model_name='testpluginmodel',
            name='field_time',
            field=models.TimeField(default=None, null=True),
        ),
    ]
