# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-05-23 08:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('test_app', '0003_auto_20171014_0359'),
    ]

    operations = [
        migrations.AddField(
            model_name='testpluginmodel',
            name='field1_fr',
            field=models.CharField(default='', max_length=64, null=True),
        ),
    ]
