# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-05 01:36
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('test_app', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestPluginModel',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='test_app_testpluginmodel', serialize=False, to='cms.CMSPlugin')),
                ('field1', models.CharField(default='', max_length=64)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.AlterField(
            model_name='testinlinemodel',
            name='field1',
            field=models.CharField(default='', max_length=64),
        ),
        migrations.AlterField(
            model_name='testmodel',
            name='field1',
            field=models.CharField(default='', max_length=64),
        ),
    ]
