
// just hide the publish button, always, as sometimes, autopublish is done before the page is marked "dirty"
// include this file in your main base.html
// <link rel="stylesheet" href="{{ STATIC_URL }}djangocms_misc/css/autopublisher.css">


/* hide publish button */
.cms-btn-publish-active
    display: none
